use std::{fs::File, io::{Read, Write}};
use env_logger::Builder;
use log::{error, info, LevelFilter};
use xobjects::{XArgument, XSomeList};

mod objects;
mod xobjects;
mod deserializer;
mod serializer;

/*
[lib]
crate-type = ["staticlib", "cdylib", "lib"]
*/

fn main() {

    // Initialize the logger with 'info' as the default level
    Builder::new()
        .filter(None, LevelFilter::Info)
        .init();

    // /Users/michael/Documents/ipod/iTunes/iTunesDB
    let mut f = File::open("D:\\Documents\\iTunes\\iTunesDB").unwrap(); // D:\\Documents\\iTunes\\iTunesDB
    let mut buf = Vec::new();
    match f.read_to_end(&mut buf) {
        Ok(n) => {
            let data = &buf[..n];
            let mut xdb = deserializer::parse_bytes(data);
            //info!("XDB: {:#?}", xdb);
            if let XSomeList::TrackList(tracks) = &mut xdb.find_dataset(1).child {
                let mut item = (*tracks.last().unwrap()).clone();
                let mut xargs = Vec::new();
                xargs.push(XArgument { arg_type: 1, val: String::from("They beat you") });
                xargs.push(XArgument { arg_type: 3, val: String::from("IC3PEAK EP") });
                xargs.push(XArgument { arg_type: 4, val: String::from("IC3PEAK") });
                xargs.push(XArgument { arg_type: 6, val: String::from("MPEG audio file")});
                xargs.push(XArgument { arg_type: 2, val: String::from(":iPod_Control:Music:F38:ZJUQ.mp3") });
                item.args = xargs;
                item.data.number_of_strings = 5;
                item.data.unique_id = 99;
                tracks.push(item);
            }
            let mut op = File::create("outdb").unwrap();
            info!("Write res: {:?}", op.write(&serializer::to_bytes(xdb)));
        },
        Err(e) => {
            error!("Error: {}",e);
        }
    }
}
